@@ -12,25 +12,31 @@ pcr <- function(y, x, k = 1, xnew = NULL) {
   ## y is the univariate dependent variable
   ## x contains the independent variables
   ## k shows the number of components to keep
-  m <- mean(y)
-  y <- y - m  ## standardize the dependent variable
-  p <- dim(x)[2]
+  my <- mean(y)
+  y <- y - my  ## standardize the dependent variable
+  dm <- dim(x)
+  n <- dm[1]
+  p <- dm[2]
   if (k > p)   k <- p
-  eig <- prcomp(x, center = TRUE, scale = TRUE)
+  m <- Rfast::colmeans(x)
+  s <- Rfast::colVars(x, suma = n * m, std = TRUE)
+  x <- t(x) - m
+  x <- x/s
+  x <- t(x)
+  eig <- prcomp(x, center = FALSE, scale = FALSE)
   values <- eig$sdev^2
   per <- cumsum( values / sum(values) )  ## cumulative proportion of each eigenvalue
   vec <- eig$rotation[, 1:k, drop = FALSE]
   z <- x %*% vec  ## PCA scores
-  zk <- Rfast::colsums(z^2)
-  zzk <- matrix(0, k, k)
-  diag(zzk) <- zk
-  A <- vec %*% chol2inv( chol(zzk) )
-  be <- A %*% crossprod( z, y )  ## PCA based coefficients
+  zzk <- crossprod(z)
+  be <- vec %*% Rfast::spdinv(zzk) %*% crossprod( z, y )  ## PCA based coefficients
   est <- NULL
   if ( !is.null(xnew) ) {
     xnew <- matrix(xnew, ncol = p)
-    est <- as.vector( m + xnew %*% be )  ## predicted values for PCA model
+    xnew <- t(xnew) - m
+    xnew <- t( xnew / s )
+    est <- as.vector( my + xnew %*% be )  ## predicted values for PCA model
   }
   rownames(be) <- colnames(x)
-  list(parameters = be, per = per[k], est = est)
+  list(be = be, per = per[k], est = est)
 }
